%ifarch x86_64 ppc64le
%define alt_ckbi  libnssckbi.so.%{_arch}
%else
%define alt_ckbi  libnssckbi.so
%endif

Summary:        Provides a way to load and enumerate PKCS#11 modules
Name:           p11-kit
Version:        0.25.0
Release:        2%{?dist}
License:        BSD
URL:            http://p11-glue.freedesktop.org/p11-kit.html
Source0:        https://github.com/p11-glue/p11-kit/releases/download/%{version}/p11-kit-%{version}.tar.xz
Source1:        trust-extract-compat
Source2:        p11-kit-client.service

BuildRequires:  gcc meson
BuildRequires:  libtasn1-devel >= 2.3
BuildRequires:  libffi-devel gettext gtk-doc
BuildRequires:  systemd-devel bash-completion pkgconfig(glib-2.0) /usr/bin/xsltproc

%description
Provides a way to load and enumerate PKCS#11 modules. Provides
a standard configuration setup for installing PKCS#11 modules
in such a way that they're discoverable. Also solves problems
with coordinating the use of PKCS#11 by different components
or libraries living in the same process.

%package devel
Summary:        Development files for p11-kit
Requires:       %{name} = %{version}-%{release}

%description devel
This package includes header files, libraries necessary for
developing programs which use p11-kit library.

%package trust
Summary:            System trust module from p11-kit
Requires:           %{name} = %{version}-%{release}
Requires(post):     %{_sbindir}/update-alternatives
Requires(postun):   %{_sbindir}/update-alternatives

%description trust
This package inclides a system trust PKCS#11 module which
contains certificate anchors and black lists.

%package server
Summary:        Server and client commands for p11-kit
Requires:       %{name} = %{version}-%{release}

%description server
This package contains command line tools that enable to export
PKCS#11 modules through a Unix domain socket.  Note that this
feature is still experimental.

%prep
%autosetup

%build
%meson -Dgtk_doc=true -Dman=true -Dtrust_paths=%{_sysconfdir}/pki/ca-trust/source:%{_datadir}/pki/ca-trust-source
%meson_build

%install
%meson_install
mkdir -p %{buildroot}%{_sysconfdir}/pkcs11/modules
install -p -m 755 %{SOURCE1} %{buildroot}%{_libexecdir}/p11-kit/
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_sysconfdir}/pkcs11/pkcs11.conf.example %{buildroot}%{_docdir}/%{name}/pkcs11.conf.example
mkdir -p %{buildroot}%{_userunitdir}
install -p -m 644 %{SOURCE2} %{buildroot}%{_userunitdir}
%find_lang %{name}

%check
%meson_test

%post trust
%{_sbindir}/update-alternatives --install %{_libdir}/libnssckbi.so \
        %{alt_ckbi} %{_libdir}/pkcs11/p11-kit-trust.so 30

%postun trust
if [ $1 -eq 0 ] ; then
        %{_sbindir}/update-alternatives --remove %{alt_ckbi} %{_libdir}/pkcs11/p11-kit-trust.so
fi

%files -f %{name}.lang
%license COPYING
%doc AUTHORS NEWS README
%{_docdir}/%{name}/pkcs11.conf.example
%dir %{_sysconfdir}/pkcs11
%dir %{_sysconfdir}/pkcs11/modules
%dir %{_datadir}/p11-kit
%dir %{_datadir}/p11-kit/modules
%dir %{_libexecdir}/p11-kit
%{_bindir}/p11-kit
%{_libdir}/libp11-kit.so.*
%{_libdir}/p11-kit-proxy.so
%{_libexecdir}/p11-kit/p11-kit-remote
%{_mandir}/man1/trust.1.gz
%{_mandir}/man8/p11-kit.8.gz
%{_mandir}/man5/pkcs11.conf.5.gz
%{_datadir}/bash-completion/completions/p11-kit

%files devel
%{_includedir}/p11-kit-1/
%{_libdir}/libp11-kit.so
%{_libdir}/pkgconfig/p11-kit-1.pc
%doc %{_datadir}/gtk-doc/

%files trust
%{_bindir}/trust
%dir %{_libdir}/pkcs11
%ghost %{_libdir}/libnssckbi.so
%{_libdir}/pkcs11/p11-kit-trust.so
%{_datadir}/p11-kit/modules/p11-kit-trust.module
%{_libexecdir}/p11-kit/trust-extract-compat
%{_datadir}/bash-completion/completions/trust

%files server
%{_libdir}/pkcs11/p11-kit-client.so
%{_userunitdir}/p11-kit-client.service
%{_libexecdir}/p11-kit/p11-kit-server
%{_userunitdir}/p11-kit-server.service
%{_userunitdir}/p11-kit-server.socket

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.25.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 15 2023 kianli <kianli@tencent.com> - 0.25.0-1
- Upgrade to 0.25.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.24.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.24.1-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Aug 24 2022 ZoeDong <zoedong@tencent.com> - 0.24.1-1
- Initial build

